@@ -5,10 +5,6 @@ import json
 import uuid
 from logging import basicConfig, INFO, getLogger
 from logging import getLogRecordFactory, setLogRecordFactory
-from pathlib import Path
-
-PATH_SRC = Path(__file__).parents[1]
-PATH_LOG = PATH_SRC / 'logs'
 
 
 # unique export id
@@ -23,7 +19,7 @@ basicConfig(format=json.dumps({'created_at': '%(asctime)s',
                                'log_message': '%(message)s'}
                               ),
             level=INFO,
-            filename=Path(PATH_LOG, 'rdf_logging.log'),
+            filename='rdf_logging.log',
             )
 old_factory = getLogRecordFactory()
 
